/*   ORDONARE (SORTARE)
 * 	  
 *   Algoritmul: Sortare prin Selectia Minimului (Selection Sort)
 * 
 *   Ideea: Pentru fiecare pozitie i = [1... n - 1]
 *          - cautam pozitia pmin a minimului in intervalul [i...n]
 *          - interschimbam a[i] cu a[pmin]
 * 
 *   Complexitatea algoritmului: O(n^2)
 */ 
#include <fstream>
#include <algorithm>
using namespace std;

ifstream fin("selection_sort.in");
ofstream fout("selection_sort.out");

const int Dim = 1001;

int a[Dim], n;

void CitesteSir();
void SorteazaSir();
void AfiseazaSir();


int main()
{
	CitesteSir();
	SorteazaSir();
	AfiseazaSir();
	
	return 0;
}

// Calculul numarului de operatii:
// i = 1: n - 1
// i = 2: n - 2
// .....
// i = n - 1: j = 1
// NrOp = 1 + 2 + 3 + ... + n - 1 = n * (n - 1) / 2
// NrOp = n^2 / 2 - n / 2 => O(n * n)

void SorteazaSir()  // O(n * n)
{
	int aux;
	int pmin; // pozitia minimului in intervalul de pozitii [i ... n]
	
	for (int i = 1; i < n; ++i)
	{
		pmin = i;
		
		for (int j = i + 1; j <= n; ++j)
			if (a[j] < a[pmin])
				pmin = j;
		
		if (i != pmin)
		{
			aux = a[i];
			a[i] = a[pmin];
			a[pmin] = aux;
		}
	}
}

void AfiseazaSir()
{
	for (int i = 1; i <= n; ++i)
		fout << a[i] << ' ';
}

void CitesteSir()
{
	fin >> n;
	for (int i = 1; i <= n; ++i)
		fin >> a[i];
}


